[cp-patches] FYI: MetalFileChooserUI

2005-09-21 Thread David Gilbert
I started some work on MetalFileChooserUI and have committed the inner classes and 
methods that I'm confident are complete.  The missing pieces mean this class can't 
be used for anything useful yet, but I think the bits that are complete should be in 
CVS for others to see and hack on, so here it is:


2005-09-21  David Gilbert  [EMAIL PROTECTED]

* javax/swing/plaf/metal/MetalFileChooserUI.java: new file (partial
implementation).

Regards,

Dave
Index: javax/swing/plaf/metal/MetalFileChooserUI.java
===
RCS file: javax/swing/plaf/metal/MetalFileChooserUI.java
diff -N javax/swing/plaf/metal/MetalFileChooserUI.java
--- /dev/null   1 Jan 1970 00:00:00 -
+++ javax/swing/plaf/metal/MetalFileChooserUI.java  21 Sep 2005 10:53:28 
-
@@ -0,0 +1,346 @@
+/* MetalFileChooserUI.java --
+   Copyright (C) 2005 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING.  If not, write to the
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
+
+Linking this library statically or dynamically with other modules is
+making a combined work based on this library.  Thus, the terms and
+conditions of the GNU General Public License cover the whole
+combination.
+
+As a special exception, the copyright holders of this library give you
+permission to link this library with independent modules to produce an
+executable, regardless of the license terms of these independent
+modules, and to copy and distribute the resulting executable under
+terms of your choice, provided that you also meet, for each linked
+independent module, the terms and conditions of the license of that
+module.  An independent module is a module which is not derived from
+or based on this library.  If you modify this library, you may extend
+this exception to your version of the library, but you are not
+obligated to do so.  If you do not wish to do so, delete this
+exception statement from your version. */
+
+
+package javax.swing.plaf.metal;
+
+import java.awt.Component;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
+import java.io.File;
+import java.util.List;
+
+import javax.swing.AbstractListModel;
+import javax.swing.ComboBoxModel;
+import javax.swing.DefaultListCellRenderer;
+import javax.swing.JComponent;
+import javax.swing.JFileChooser;
+import javax.swing.JList;
+import javax.swing.filechooser.FileFilter;
+import javax.swing.filechooser.FileSystemView;
+import javax.swing.plaf.ComponentUI;
+import javax.swing.plaf.basic.BasicFileChooserUI;
+
+
+/**
+ * A UI delegate for the [EMAIL PROTECTED] JFileChooser} component.  This 
class is only
+ * partially implemented and is not usable yet.
+ */
+public class MetalFileChooserUI 
+  extends BasicFileChooserUI
+{
+  /** 
+   * A combo box model containing the selected directory and all its parent
+   * directories.
+   */
+  protected class DirectoryComboBoxModel
+extends AbstractListModel
+implements ComboBoxModel
+  {
+/** Storage for the items in the model. */
+private List items;
+
+/** The index of the selected item. */
+private int selectedIndex;
+
+/**
+ * Creates a new model.
+ */
+public DirectoryComboBoxModel() 
+{
+  items = new java.util.ArrayList();
+  selectedIndex = -1;
+}
+
+/**
+ * Returns the number of items in the model.
+ * 
+ * @return The number of items in the model.
+ */
+public int getSize()
+{
+  return items.size();
+}
+
+/**
+ * Returns the item at the specified index.
+ * 
+ * @param index  the item index.
+ * 
+ * @return The item.
+ */
+public Object getElementAt(int index)
+{
+  return items.get(index);
+}
+
+/**
+ * Returns the depth of the item at the given codeindex/code.
+ * 
+ * @param index  the item index.
+ * 
+ * @return The depth.
+ */
+public int getDepth(int index)
+{
+  return Math.max(index, 0);
+}
+
+/**
+ * Returns the selected item, or codenull/code if no item is selected.
+ * 
+ * @return The selected item, or codenull/code.
+ */
+public Object getSelectedItem()
+{
+  if (selectedIndex = 0) 
+return items.get(selectedIndex);
+  else
+return null;
+

Re: [cp-patches]: FYI: ToolTip fix

2005-09-21 Thread Lillian Angel
I fixed this so the Tool Tips are painted in a better location.

2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/ToolTipManager.java
(showTip): Added code to move currentPoint to a new place.
(getGoodPoint): Removed, not needed.


On Tue, 2005-09-20 at 18:00 -0400, Lillian Angel wrote:
 2005-09-20  Lillian Angel  [EMAIL PROTECTED]
 
 * javax/swing/JPopupMenu.java
 (setVisible): If HeavyWeightPopup, setLightWeightPopupEnabled
 is false.
 * javax/swing/ToolTipManager.java
 (showTip): Change so toolTips on lightWeightPopups are
 added different than those on heavyWeightPopups.
 (canToolTipFit): Removed. This is not needed/used.
 
 ___
 Classpath-patches mailing list
 Classpath-patches@gnu.org
 http://lists.gnu.org/mailman/listinfo/classpath-patches
Index: javax/swing/ToolTipManager.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/ToolTipManager.java,v
retrieving revision 1.16
diff -u -r1.16 ToolTipManager.java
--- javax/swing/ToolTipManager.java	20 Sep 2005 22:00:54 -	1.16
+++ javax/swing/ToolTipManager.java	21 Sep 2005 14:19:47 -
@@ -475,8 +475,13 @@
 if (parent instanceof JPopupMenu)
   setLightWeightPopupEnabled(((JPopupMenu) parent).isLightWeightPopupEnabled());
 
+// Moves currentPoint to an appropriate place
 Point p = currentPoint;
 Dimension dims = currentTip.getPreferredSize();
+Rectangle bounds = currentComponent.getBounds();
+p.x = bounds.width - dims.width;
+p.y = bounds.height;
+
 if (isLightWeightPopupEnabled())
   {
 JLayeredPane pane = ((JRootPane) SwingUtilities.
@@ -486,9 +491,9 @@
 // This should never happen, but just in case.
 if (pane == null)
   return;
-
 if (containerPanel != null)
   hideTip();
+
 containerPanel = new Panel();
 JRootPane root = new JRootPane();
 root.getContentPane().add(currentTip);
@@ -502,7 +507,7 @@
 fm.setHgap(0);
   }
 
-p = getGoodPoint(currentPoint, pane, currentTip, dims);
+p = SwingUtilities.convertPoint(currentComponent, p, pane);
 pane.add(containerPanel);
 containerPanel.setBounds(p.x, p.y, dims.width, dims.height);
 currentTip.setBounds(0, 0, dims.width, dims.height);
@@ -558,35 +563,6 @@
 	tooltipWindow.dispose();
 	tooltipWindow = null;
   }
-  }
-
-  /**
-   * This method returns a point in the LayeredPane where the ToolTip can be
-   * shown. The point returned (if the ToolTip is to be displayed at the
-   * preferred dimensions) will always place the ToolTip inside the
-   * currentComponent if possible.
-   *
-   * @param p The last known good point for the mouse.
-   * @param c The JLayeredPane in the first RootPaneContainer up from the
-   *currentComponent.
-   * @param tip The ToolTip to display.
-   * @param dims The ToolTip preferred dimensions (can be null).
-   *
-   * @return A good point to place the ToolTip.
-   */
-  private Point getGoodPoint(Point p, JLayeredPane c, JToolTip tip,
- Dimension dims)
-  {
-if (dims == null)
-  dims = tip.getPreferredSize();
-Rectangle bounds = currentComponent.getBounds();
-if (p.x + dims.width  bounds.width)
-  p.x += bounds.width - dims.width;
-if (p.y + dims.height  bounds.height)
-  p.y += bounds.height;
-
-p = SwingUtilities.convertPoint(currentComponent, p, c);
-return p;
   }
 
   /**
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches]: Patch: JOptionPane fix

2005-09-21 Thread Lillian Angel
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

Fixes Bug #23937
* javax/swing/plaf/basic/BasicOptionPaneUI.java
(propertyChange): When WANTS_INPUT_PROPERTY is changed,
the buttons should be updated.
(getButtons): Applied patch in bug report. Sets default
buttons.

Index: javax/swing/plaf/basic/BasicOptionPaneUI.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/plaf/basic/BasicOptionPaneUI.java,v
retrieving revision 1.23
diff -u -r1.23 BasicOptionPaneUI.java
--- javax/swing/plaf/basic/BasicOptionPaneUI.java	15 Sep 2005 14:03:36 -	1.23
+++ javax/swing/plaf/basic/BasicOptionPaneUI.java	21 Sep 2005 15:31:28 -
@@ -405,10 +405,14 @@
|| e.getPropertyName().equals(JOptionPane.WANTS_INPUT_PROPERTY)
|| e.getPropertyName().equals(JOptionPane.SELECTION_VALUES_PROPERTY))
 {
-	  optionPane.removeAll();
-	  messageAreaContainer = createMessageArea();
-	  optionPane.add(messageAreaContainer);
-	  optionPane.add(buttonContainer);
+  optionPane.remove(messageAreaContainer);
+  messageAreaContainer = createMessageArea();
+  optionPane.add(messageAreaContainer);
+  Container newButtons = createButtonArea();
+  optionPane.remove(buttonContainer);
+  optionPane.add(newButtons);
+  buttonContainer = newButtons;
+  optionPane.add(buttonContainer);
 }
   optionPane.invalidate();
   optionPane.repaint();
@@ -941,11 +945,17 @@
   {
   case JOptionPane.YES_NO_OPTION:
 	return new Object[] { YES_STRING, NO_STRING };
-  case JOptionPane.DEFAULT_OPTION:
   case JOptionPane.YES_NO_CANCEL_OPTION:
 	return new Object[] { YES_STRING, NO_STRING, CANCEL_STRING };
   case JOptionPane.OK_CANCEL_OPTION:
 	return new Object[] { OK_STRING, CANCEL_STRING };
+  case JOptionPane.DEFAULT_OPTION:
+return (optionPane.getWantsInput() ) ?
+   new Object[] { OK_STRING, CANCEL_STRING } :
+   ( optionPane.getMessageType() == JOptionPane.QUESTION_MESSAGE ) ?
+   new Object[] { YES_STRING, NO_STRING, CANCEL_STRING } :
+   // ERROR_MESSAGE, INFORMATION_MESSAGE, WARNING_MESSAGE, PLAIN_MESSAGE
+   new Object[] { OK_STRING };
   }
 return null;
   }
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] Patch: FYI: minor 1.5-isms in java.math

2005-09-21 Thread Tom Tromey
I'm checking this in.

This is a couple of 1.5 changes in java.math -- mostly making some
existing members 'public', but also adding a couple new constants.

Tom

Index: ChangeLog
from  Tom Tromey  [EMAIL PROTECTED]

* java/math/BigDecimal.java (ZERO, ONE): Now public.  Updated
javadoc.
(TEN): New constant.
* java/math/BigInteger.java (ZERO): Updated javadoc.
(ONE): Likewise.
(TEN): New constant.

Index: java/math/BigDecimal.java
===
RCS file: /cvsroot/classpath/classpath/java/math/BigDecimal.java,v
retrieving revision 1.19
diff -u -r1.19 BigDecimal.java
--- java/math/BigDecimal.java   2 Jul 2005 20:32:39 -   1.19
+++ java/math/BigDecimal.java   21 Sep 2005 16:59:08 -
@@ -43,11 +43,26 @@
   private int scale;
   private static final long serialVersionUID = 6108874887143696463L;
 
-  private static final BigDecimal ZERO = 
+  /**
+   * The constant zero as a BigDecimal with scale zero.
+   * @since 1.5
+   */
+  public static final BigDecimal ZERO = 
 new BigDecimal (BigInteger.valueOf (0), 0);
 
-  private static final BigDecimal ONE = 
+  /**
+   * The constant one as a BigDecimal with scale zero.
+   * @since 1.5
+   */
+  public static final BigDecimal ONE = 
 new BigDecimal (BigInteger.valueOf (1), 0);
+
+  /**
+   * The constant ten as a BigDecimal with scale zero.
+   * @since 1.5
+   */
+  public static final BigDecimal TEN = 
+new BigDecimal (BigInteger.valueOf (10), 0);
 
   public static final int ROUND_UP = 0;
   public static final int ROUND_DOWN = 1;
Index: ChangeLog
from  Tom Tromey  [EMAIL PROTECTED]
* java/awt/BorderLayout.java (invalidateLayout): Updated comment.
(setBounds): Likewise.
(MIN, MAX, PREF): Moved nearer top of file.
(getLayoutComponent): New methods.
(getConstraints): New method.
(vgap, hgap, north, south, east, west): Reordered fields to conform
to serialization spec.

Index: java/awt/BorderLayout.java
===
RCS file: /cvsroot/classpath/classpath/java/awt/BorderLayout.java,v
retrieving revision 1.18
diff -u -r1.18 BorderLayout.java
--- java/awt/BorderLayout.java  4 Aug 2005 18:10:44 -   1.18
+++ java/awt/BorderLayout.java  21 Sep 2005 18:23:55 -
@@ -38,6 +38,7 @@
 
 package java.awt;
 
+
 /**
   * This class implements a layout manager that positions components
   * in certain sectors of the parent container.
@@ -174,6 +175,16 @@
 
 
   /**
+   * @serial The horizontal gap between components
+   */
+  private int hgap;
+
+  /**
+   * @serial The vertical gap between components
+   */
+  private int vgap;
+
+  /**
* @serial
*/
   private Component north;
@@ -181,7 +192,7 @@
   /**
* @serial
*/
-  private Component south;
+  private Component west;
 
   /**
* @serial
@@ -191,7 +202,7 @@
   /**
* @serial
*/
-  private Component west;
+  private Component south;
 
   /**
* @serial
@@ -218,15 +229,11 @@
*/
   private Component lastItem;
 
-  /**
-   * @serial The horizontal gap between components
-   */
-  private int hgap;
 
-  /**
-   * @serial The vertical gap between components
-   */
-  private int vgap;
+  // Some constants for use with calcSize().
+  private static final int MIN = 0;
+  private static final int MAX = 1;
+  private static final int PREF = 2;
 
 
   /**
@@ -449,7 +456,7 @@
*/
   public void invalidateLayout(Container parent)
   {
-// FIXME: Implement this properly!
+// Nothing to do here.
   }
 
   /**
@@ -560,7 +567,8 @@
   }
 
   /**
-   * FIXME: Document me!
+   * This is a convenience method to set the bounds on a component.
+   * If the indicated component is null, nothing is done.
*/
   private void setBounds(Component comp, int x, int y, int w, int h)
   {
@@ -569,12 +577,6 @@
 comp.setBounds(x, y, w, h);
   }
 
-  // FIXME: Maybe move to top of file.
-  // Some constants for use with calcSize().
-  private static final int MIN = 0;
-  private static final int MAX = 1;
-  private static final int PREF = 2;
-
   private Dimension calcCompSize(Component comp, int what)
   {
 if (comp == null || !comp.isVisible())
@@ -659,5 +661,113 @@
 
 return(new Dimension(width, height));
   }
+  }
+
+  /**
+   * Return the component at the indicated location, or null if no component
+   * is at that location.  The constraints argument must be one of the 
+   * location constants specified by this class.   
+   * @param constraints the location
+   * @return the component at that location, or null
+   * @throws IllegalArgumentException if the constraints argument is not 
+   * recognized
+   * @since 1.5
+   */
+  public Component getLayoutComponent(Object constraints)
+  {
+if (constraints == CENTER)
+  return center;
+if (constraints == NORTH)
+  return north;
+if (constraints == EAST)
+  return east;
+if (constraints == SOUTH)
+  return south;
+if (constraints == WEST)
+  return west;
+if (constraints == PAGE_START)
+  return firstLine;
+if (constraints == PAGE_END)
+  return lastLine;
+if (constraints == LINE_START)
+  return firstItem;
+if (constraints == LINE_END)
+  return lastItem;
+throw new IllegalArgumentException(constraint  + constraints 
+   +  is not recognized);
+  }
+
+  /**
+   * Return the component at the specified location, which must be one
+   * of the absolute constants such as CENTER or SOUTH.  The container's
+   * orientation is used to map this location to the correct corresponding
+   * component, so for instance in a right-to-left container, a request
+   * for the EAST component could return the LINE_END component.  This will
+   * return null if no component is available at the given location.
+   * @param container the container whose orientation is used
+   * @param constraints the absolute location of the component
+   * @return the component at the location, or null
+   * @throws IllegalArgumentException if the constraint is not recognized
+   */
+  public Component getLayoutComponent(Container container, Object constraints)
+  {
+ComponentOrientation orient = container.getComponentOrientation();
+if (constraints == CENTER)
+  return center;
+// Note that we don't support vertical 

[cp-patches] FYI: HTMLDocument.Iterator implemented

2005-09-21 Thread Anthony Balkissoon
More work done on the HTML package, added abstract class Iterator to
HTMLDocument and extended it with LeafIterator, also in HTMLDocument.
Patch is attached.

2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTMLDocument.java:
(LeafIterator): New class.
(getIterator): Implemented.
(Iterator): New abstract class.

--Tony
Index: javax/swing/text/html/HTMLDocument.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/html/HTMLDocument.java,v
retrieving revision 1.2
diff -u -r1.2 HTMLDocument.java
--- javax/swing/text/html/HTMLDocument.java	2 Jul 2005 20:32:51 -	1.2
+++ javax/swing/text/html/HTMLDocument.java	21 Sep 2005 18:18:06 -
@@ -38,7 +38,10 @@
 
 package javax.swing.text.html;
 
+import javax.swing.text.AttributeSet;
 import javax.swing.text.DefaultStyledDocument;
+import javax.swing.text.ElementIterator;
+import javax.swing.text.html.HTML.Tag;
 
 /**
  * TODO: This class is not yet completetely implemented.
@@ -47,7 +50,146 @@
  */
 public class HTMLDocument extends DefaultStyledDocument
 {
+
+  /**
+   * An iterator to iterate through LeafElements in the document.
+   */
+  class LeafIterator extends Iterator
+  {
+HTML.Tag tag;
+HTMLDocument doc;
+ElementIterator it;
+
+public LeafIterator (HTML.Tag t, HTMLDocument d)
+{
+  doc = d;
+  tag = t;
+  it = new ElementIterator(doc);
+}
+
+/**
+ * Return the attributes for the tag associated with this iteartor
+ * @return the AttributeSet
+ */
+public AttributeSet getAttributes()
+{
+  if (it.current() != null)
+return it.current().getAttributes();
+  return null;
+}
+
+/**
+ * Get the end of the range for the current occurrence of the tag
+ * being defined and having the same attributes.
+ * @return the end of the range
+ */
+public int getEndOffset()
+{
+  if (it.current() != null)
+return it.current().getEndOffset();
+  return -1;
+}
+
+/**
+ * Get the start of the range for the current occurrence of the tag
+ * being defined and having the same attributes.
+ * @return the start of the range (-1 if it can't be found).
+ */
+
+public int getStartOffset()
+{
+  if (it.current() != null)
+return it.current().getStartOffset();
+  return -1;
+}
+
+/**
+ * Advance the iterator to the next LeafElement .
+ */
+public void next()
+{
+  it.next();
+  while (it.current()!= null  !it.current().isLeaf())
+it.next();
+}
+
+/**
+ * Indicates whether or not the iterator currently represents an occurrence
+ * of the tag.
+ * @return true if the iterator currently represents an occurrence of the
+ * tag.
+ */
+public boolean isValid()
+{
+  return it.current() != null;
+}
+
+/**
+ * Type of tag for this iterator.
+ */
+public Tag getTag()
+{
+  return tag;
+}
+
+  }
+
   public void processHTMLFrameHyperlinkEvent(HTMLFrameHyperlinkEvent event)
   {
+  }
+  
+  /**
+   * Gets an iterator for the given HTML.Tag.
+   * @param t the requested HTML.Tag
+   * @return the Iterator
+   */
+  public HTMLDocument.Iterator getIterator (HTML.Tag t)
+  {
+return new HTMLDocument.LeafIterator(t, this);
+  }
+  
+  /**
+   * An iterator over a particular type of tag.
+   */
+  public abstract static class Iterator
+  {
+/**
+ * Return the attribute set for this tag.
+ * @return the codeAttributeSet/code (null if none found).
+ */
+public abstract AttributeSet getAttributes();
+
+/**
+ * Get the end of the range for the current occurrence of the tag
+ * being defined and having the same attributes.
+ * @return the end of the range
+ */
+public abstract int getEndOffset();
+
+/**
+ * Get the start of the range for the current occurrence of the tag
+ * being defined and having the same attributes.
+ * @return the start of the range (-1 if it can't be found).
+ */
+public abstract int getStartOffset();
+
+/**
+ * Move the iterator forward.
+ */
+public abstract void next();
+
+/**
+ * Indicates whether or not the iterator currently represents an occurrence
+ * of the tag.
+ * @return true if the iterator currently represents an occurrence of the
+ * tag.
+ */
+public abstract boolean isValid();
+
+/**
+ * Type of tag this iterator represents.
+ * @return the tag.
+ */
+public abstract HTML.Tag getTag();
   }
 }
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches]: Patch: ToolTip repainting fix

2005-09-21 Thread Lillian Angel
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/JTable.java
(distributeSpill): Fixed a NPE.
* javax/swing/ToolTipManager.java
(mouseExited): No need to do this stuff, removed code.
(showTip): Revalidating and repainting too much, removed.
(hideTip): Likewise.


Index: javax/swing/JTable.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.47
diff -u -r1.47 JTable.java
--- javax/swing/JTable.java	20 Sep 2005 14:46:18 -	1.47
+++ javax/swing/JTable.java	21 Sep 2005 18:53:09 -
@@ -1983,7 +1983,8 @@
 int average = spill / cols.length;
 for (int i = 0; i  cols.length; i++)
   {
-cols[i].setWidth(cols[i].getWidth() + average);
+if (cols[i] != null)
+  cols[i].setWidth(cols[i].getWidth() + average);
   }
   }
 
Index: javax/swing/ToolTipManager.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/ToolTipManager.java,v
retrieving revision 1.17
diff -u -r1.17 ToolTipManager.java
--- javax/swing/ToolTipManager.java	21 Sep 2005 14:22:21 -	1.17
+++ javax/swing/ToolTipManager.java	21 Sep 2005 18:53:09 -
@@ -421,13 +421,6 @@
 	insideTimer.stop();
 	hideTip();
   }
-
-if (currentComponent == null)
-  	  currentComponent = (Component) event.getSource();
-
-currentComponent.invalidate();
-currentComponent.validate();
-currentComponent.repaint();
   }
 
   /**
@@ -511,8 +504,6 @@
 pane.add(containerPanel);
 containerPanel.setBounds(p.x, p.y, dims.width, dims.height);
 currentTip.setBounds(0, 0, dims.width, dims.height);
-pane.revalidate();
-pane.repaint();
   }
 else if (currentComponent.isShowing())
   {
@@ -546,9 +537,6 @@
 	if (parent == null)
 	  return;
 	parent.remove(containerPanel);
-	parent.invalidate();
-	parent.validate();
-	parent.repaint();
 
 	parent = currentTip.getParent();
 	if (parent == null)
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


Re: [cp-patches] Patch: FYI: BorderLayout -vs- 1.5

2005-09-21 Thread Mark Wielaard
Hi Tom,

On Wed, 2005-09-21 at 12:22 -0600, Tom Tromey wrote:
 This also fixes the serialization of this class.
 
 I've added a Mauve test for the new methods.
 [...]
   (vgap, hgap, north, south, east, west): Reordered fields to conform
   to serialization spec.

Why? You have a serialVersionUID defined so serialization of fields
doesn't depend on the order in the source or class file. Or am I missing
something?

Cheers,

Mark


signature.asc
Description: This is a digitally signed message part
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] FYI: HTMLDocument.BlockElement partially implemented

2005-09-21 Thread Anthony Balkissoon
Implemented some simple getter/setter methods in HTMLDocument and
partially implemented the BlockElement class as well.  Patch attached.

2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTMLDocument.java:
(getBase): Implemented.
(setBase): Implemented.
(getPreservesUnknownTags): Implemented.
(setPreservesUnknownTags): Implemented.
(BlockElement): New class partially implemented.

--Tony
Index: javax/swing/text/html/HTMLDocument.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/html/HTMLDocument.java,v
retrieving revision 1.3
diff -u -r1.3 HTMLDocument.java
--- javax/swing/text/html/HTMLDocument.java	21 Sep 2005 18:21:57 -	1.3
+++ javax/swing/text/html/HTMLDocument.java	21 Sep 2005 19:23:36 -
@@ -38,9 +38,14 @@
 
 package javax.swing.text.html;
 
+import java.net.URL;
+
+import javax.swing.text.AbstractDocument;
 import javax.swing.text.AttributeSet;
 import javax.swing.text.DefaultStyledDocument;
+import javax.swing.text.Element;
 import javax.swing.text.ElementIterator;
+import javax.swing.text.AbstractDocument.BranchElement;
 import javax.swing.text.html.HTML.Tag;
 
 /**
@@ -50,7 +55,48 @@
  */
 public class HTMLDocument extends DefaultStyledDocument
 {
-
+  URL baseURL = null;
+  boolean preservesUnknownTags = true;
+  
+  /**
+   * Returns the location against which to resolve relative URLs.
+   * This is the document's URL if the document was loaded from a URL.
+   * If a codebase/code tag is found, it will be used.
+   * @return the base URL
+   */
+  public URL getBase()
+  {
+return baseURL;
+  }
+  
+  /**
+   * Sets the location against which to resolve relative URLs.
+   * @param u the new base URL
+   */
+  public void setBase(URL u)
+  {
+baseURL = u;
+//TODO: also set the base of the StyleSheet
+  }
+  
+  /**
+   * Returns whether or not the parser preserves unknown HTML tags.
+   * @return true if the parser preserves unknown tags
+   */
+  public boolean getPreservesUnknownTags()
+  {
+return preservesUnknownTags;
+  }
+  
+  /**
+   * Sets the behaviour of the parser when it encounters unknown HTML tags.
+   * @param preservesTags true if the parser should preserve unknown tags.
+   */
+  public void setPreservesUnknownTags(boolean preservesTags)
+  {
+preservesUnknownTags = preservesTags;
+  }
+  
   /**
* An iterator to iterate through LeafElements in the document.
*/
@@ -191,5 +237,28 @@
  * @return the tag.
  */
 public abstract HTML.Tag getTag();
+  }
+  
+  public class BlockElement extends AbstractDocument.BranchElement
+  {
+public BlockElement (Element parent, AttributeSet a)
+{
+  super (parent, a);
+}
+
+/**
+ * Gets the resolving parent.  Since HTML attributes are not 
+ * inherited at the model level, this returns null.
+ */
+public AttributeSet getResolveParent()
+{
+  return null;
+}
+
+public String getName()
+{
+  //FIXME: this is supposed to do something different from the super class
+  return super.getName();
+}
   }
 }
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] License fix

2005-09-21 Thread Andrew John Hughes
I'm committing the attached patch which fixes a few remaining cases of the
wrong address within the GPL license.

2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

* gnu/classpath/ByteArray.java,
* gnu/javax/crypto/DiffieHellmanImpl.java,
* gnu/javax/crypto/GnuDHPrivateKey.java,
* gnu/javax/crypto/RSACipherImpl.java:
Fix address within GPL license.

-- 
Andrew :-)

Please avoid sending me Microsoft Office (e.g. Word, PowerPoint) attachments.
See http://www.fsf.org/philosophy/no-word-attachments.html

Value your freedom, or you will lose it, teaches history. 
`Don't bother us with politics' respond those who don't want to learn. 
-- Richard Stallman

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: gnu/classpath/ByteArray.java
===
RCS file: /cvsroot/classpath/classpath/gnu/classpath/ByteArray.java,v
retrieving revision 1.1
diff -u -3 -p -u -r1.1 ByteArray.java
--- gnu/classpath/ByteArray.java13 Sep 2005 22:09:43 -  1.1
+++ gnu/classpath/ByteArray.java21 Sep 2005 20:45:57 -
@@ -17,8 +17,8 @@ You should have received a copy of the G
 with GNU Classpath; if not, write to the
 
Free Software Foundation, Inc.,
-   59 Temple Place, Suite 330,
-   Boston, MA  02111-1307
+   51 Franklin Street, Fifth Floor,
+   Boston, MA  02110-1301
USA
 
 Linking this library statically or dynamically with other modules is
Index: gnu/javax/crypto/DiffieHellmanImpl.java
===
RCS file: /cvsroot/classpath/classpath/gnu/javax/crypto/DiffieHellmanImpl.java,v
retrieving revision 1.1
diff -u -3 -p -u -r1.1 DiffieHellmanImpl.java
--- gnu/javax/crypto/DiffieHellmanImpl.java 13 Sep 2005 22:09:43 -  
1.1
+++ gnu/javax/crypto/DiffieHellmanImpl.java 21 Sep 2005 20:45:57 -
@@ -15,8 +15,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Classpath; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA.
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
 
 Linking this library statically or dynamically with other modules is
 making a combined work based on this library.  Thus, the terms and
Index: gnu/javax/crypto/GnuDHPrivateKey.java
===
RCS file: /cvsroot/classpath/classpath/gnu/javax/crypto/GnuDHPrivateKey.java,v
retrieving revision 1.1
diff -u -3 -p -u -r1.1 GnuDHPrivateKey.java
--- gnu/javax/crypto/GnuDHPrivateKey.java   13 Sep 2005 22:09:43 -  
1.1
+++ gnu/javax/crypto/GnuDHPrivateKey.java   21 Sep 2005 20:45:57 -
@@ -15,8 +15,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Classpath; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA.
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
 
 Linking this library statically or dynamically with other modules is
 making a combined work based on this library.  Thus, the terms and
Index: gnu/javax/crypto/RSACipherImpl.java
===
RCS file: /cvsroot/classpath/classpath/gnu/javax/crypto/RSACipherImpl.java,v
retrieving revision 1.1
diff -u -3 -p -u -r1.1 RSACipherImpl.java
--- gnu/javax/crypto/RSACipherImpl.java 13 Sep 2005 22:09:43 -  1.1
+++ gnu/javax/crypto/RSACipherImpl.java 21 Sep 2005 20:45:57 -
@@ -15,8 +15,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Classpath; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA.
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
 
 Linking this library statically or dynamically with other modules is
 making a combined work based on this library.  Thus, the terms and


signature.asc
Description: Digital signature
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] FYI: 2 minor HTML fixes

2005-09-21 Thread Anthony Balkissoon
Fixed the name of the IMPLIED HTML.Tag and added the AdditionalComments
field to HTMLDocument.

2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTML.java:
(Tag): Changed name of IMPLIED Tag from implied to p-implied to 
match the JDK.
* javax/swing/text/html/HTMLDocument.java:
(AdditionalComments): New field.

--Tony
Index: javax/swing/text/html/HTML.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/html/HTML.java,v
retrieving revision 1.5
diff -u -r1.5 HTML.java
--- javax/swing/text/html/HTML.java 2 Jul 2005 20:32:51 -   1.5
+++ javax/swing/text/html/HTML.java 21 Sep 2005 20:27:29 -
@@ -960,6 +960,6 @@
  * a paragraph is manufactured.
  * toString() returns 'implied'. HTML reader synthesizes this tag.
  */
-public static final Tag IMPLIED = new Tag(implied, SYNTETIC);
+public static final Tag IMPLIED = new Tag(p-implied, SYNTETIC);
 final String name;
 final int flags;

Index: javax/swing/text/html/HTMLDocument.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/html/HTMLDocument.java,v
retrieving revision 1.4
diff -u -r1.4 HTMLDocument.java
--- javax/swing/text/html/HTMLDocument.java 21 Sep 2005 19:27:28 -  1.4
+++ javax/swing/text/html/HTMLDocument.java 21 Sep 2005 20:27:29 -
@@ -55,5 +55,9 @@
  */
 public class HTMLDocument extends DefaultStyledDocument
 {
+  /** A key for document properies.  The value for the key is
+   * a Vector of Strings of comments not found in the body.
+   */
+  public static final String AdditionalComments = AdditionalComments;
   URL baseURL = null;
   boolean preservesUnknownTags = true;

___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


Re: [cp-patches] License fix

2005-09-21 Thread Mark Wielaard
Hi Andrew,

On Wed, 2005-09-21 at 21:49 +0100, Andrew John Hughes wrote:
 I'm committing the attached patch which fixes a few remaining cases of the
 wrong address within the GPL license.

Thanks for finding and fixing these. One of these files was missed
because it used the wrong indenting. Fixed as follows:

2005-09-21  Mark Wielaard  [EMAIL PROTECTED]

* gnu/classpath/ByteArray.java: Reindent boilerplate.

Committed,

Mark
Index: gnu/classpath/ByteArray.java
===
RCS file: /cvsroot/classpath/classpath/gnu/classpath/ByteArray.java,v
retrieving revision 1.2
diff -u -r1.2 ByteArray.java
--- gnu/classpath/ByteArray.java	21 Sep 2005 20:55:40 -	1.2
+++ gnu/classpath/ByteArray.java	21 Sep 2005 21:04:38 -
@@ -1,25 +1,22 @@
 /* ByteArray.java -- wrapper around a byte array, with nice toString output.
Copyright (C) 2005  Free Software Foundation, Inc.
 
-This file is a part of GNU Classpath.
+This file is part of GNU Classpath.
 
 GNU Classpath is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or (at
-your option) any later version.
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
 
 GNU Classpath is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.
 
-You should have received a copy of the GNU General Public License along
-with GNU Classpath; if not, write to the
-
-   Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor,
-   Boston, MA  02110-1301
-   USA
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING.  If not, write to the
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
 
 Linking this library statically or dynamically with other modules is
 making a combined work based on this library.  Thus, the terms and
@@ -29,14 +26,14 @@
 As a special exception, the copyright holders of this library give you
 permission to link this library with independent modules to produce an
 executable, regardless of the license terms of these independent
-modules, and to copy and distribute the resulting executable under terms
-of your choice, provided that you also meet, for each linked independent
-module, the terms and conditions of the license of that module.  An
-independent module is a module which is not derived from or based on
-this library.  If you modify this library, you may extend this exception
-to your version of the library, but you are not obligated to do so.  If
-you do not wish to do so, delete this exception statement from your
-version.  */
+modules, and to copy and distribute the resulting executable under
+terms of your choice, provided that you also meet, for each linked
+independent module, the terms and conditions of the license of that
+module.  An independent module is a module which is not derived from
+or based on this library.  If you modify this library, you may extend
+this exception to your version of the library, but you are not
+obligated to do so.  If you do not wish to do so, delete this
+exception statement from your version. */
 
 
 package gnu.classpath;


signature.asc
Description: This is a digitally signed message part
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


Re: [cp-patches]: FYI: ToolTip fix

2005-09-21 Thread Lillian Angel

2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/ToolTipManager.java
(showTip): Fixed location of tooltip. Sometimes
the ToolTip was being cut off.


On Wed, 2005-09-21 at 10:21 -0400, Lillian Angel wrote:
 I fixed this so the Tool Tips are painted in a better location.
 
 2005-09-21  Lillian Angel  [EMAIL PROTECTED]
 
 * javax/swing/ToolTipManager.java
 (showTip): Added code to move currentPoint to a new place.
 (getGoodPoint): Removed, not needed.
 
 
 On Tue, 2005-09-20 at 18:00 -0400, Lillian Angel wrote:
  2005-09-20  Lillian Angel  [EMAIL PROTECTED]
  
  * javax/swing/JPopupMenu.java
  (setVisible): If HeavyWeightPopup, setLightWeightPopupEnabled
  is false.
  * javax/swing/ToolTipManager.java
  (showTip): Change so toolTips on lightWeightPopups are
  added different than those on heavyWeightPopups.
  (canToolTipFit): Removed. This is not needed/used.
  
  ___
  Classpath-patches mailing list
  Classpath-patches@gnu.org
  http://lists.gnu.org/mailman/listinfo/classpath-patches
 ___
 Classpath-patches mailing list
 Classpath-patches@gnu.org
 http://lists.gnu.org/mailman/listinfo/classpath-patches
Index: javax/swing/ToolTipManager.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/ToolTipManager.java,v
retrieving revision 1.18
diff -u -r1.18 ToolTipManager.java
--- javax/swing/ToolTipManager.java	21 Sep 2005 18:57:45 -	1.18
+++ javax/swing/ToolTipManager.java	21 Sep 2005 21:18:30 -
@@ -456,7 +456,7 @@
*/
   void showTip()
   {
-if (!enabled || currentComponent == null
+if (!enabled || currentComponent == null || !currentComponent.isEnabled()
 || (currentTip != null  currentTip.isVisible()))
   return;
 
@@ -465,18 +465,20 @@
   currentTip = ((JComponent) currentComponent).createToolTip();
 
 Container parent = currentComponent.getParent();
-if (parent instanceof JPopupMenu)
-  setLightWeightPopupEnabled(((JPopupMenu) parent).isLightWeightPopupEnabled());
-
-// Moves currentPoint to an appropriate place
 Point p = currentPoint;
 Dimension dims = currentTip.getPreferredSize();
 Rectangle bounds = currentComponent.getBounds();
-p.x = bounds.width - dims.width;
+p.x += bounds.width - dims.width;
 p.y = bounds.height;
-
+
+if (parent instanceof JPopupMenu)
+setLightWeightPopupEnabled(((JPopupMenu) parent).isLightWeightPopupEnabled());
+   
 if (isLightWeightPopupEnabled())
   {
+if (p.x  parent.getBounds().x)
+  p.x = 0;
+
 JLayeredPane pane = ((JRootPane) SwingUtilities.
 getAncestorOfClass(JRootPane.class, currentComponent)).
 getLayeredPane();
@@ -507,6 +509,10 @@
   }
 else if (currentComponent.isShowing())
   {
+Rectangle b = parent.getBounds();
+if (p.x + dims.width  b.x + b.width)
+  p.x = b.x - dims.width;
+
 SwingUtilities.convertPointToScreen(p, currentComponent);
 tooltipWindow = new JDialog();
 tooltipWindow.setContentPane(currentTip);
___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] [generics] License fix

2005-09-21 Thread Andrew John Hughes
I'm committing the attached patch to fix the license
address in the new generics files.

Changelog:

2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

* gnu/classpath/ByteArray.java,
* gnu/classpath/ObjectPool.java,
* gnu/javax/crypto/DiffieHellmanImpl.java,
* gnu/javax/crypto/GnuDHPrivateKey.java,
* gnu/javax/crypto/RSACipherImpl.java,
* java/lang/Deprecated.java,
* java/lang/Enum.java,
* java/lang/Iterable.java,
* java/lang/MalformedParameterizedTypeException.java,
* java/lang/Override.java,
* java/lang/ProcessBuilder.java,
* java/lang/SuppressWarnings.java,
* java/lang/annotation/Annotation.java,
* java/lang/annotation/Documented.java,
* java/lang/annotation/ElementType.java,
* java/lang/annotation/IncompleteAnnotationException.java,
* java/lang/annotation/Inherited.java,
* java/lang/annotation/Retention.java,
* java/lang/annotation/RetentionPolicy.java,
* java/lang/annotation/Target.java,
* java/lang/reflect/AnnotatedElement.java,
* java/lang/reflect/GenericDeclaration.java,
* java/lang/reflect/MalformedParameterizedTypeException.java,
* java/lang/reflect/TypeVariable.java,
* java/util/AbstractQueue.java,
* java/util/DuplicateFormatFlagsException.java,
* java/util/EnumMap.java,
* java/util/EnumSet.java,
* java/util/FormatFlagsConversionMismatchException.java,
* java/util/FormatterClosedException.java,
* java/util/IllegalFormatCodePointException.java,
* java/util/IllegalFormatConversionException.java,
* java/util/IllegalFormatException.java,
* java/util/IllegalFormatFlagsException.java,
* java/util/IllegalFormatPrecisionException.java,
* java/util/IllegalFormatWidthException.java,
* java/util/InputMismatchException.java,
* java/util/InvalidPropertiesFormatException.java,
* java/util/MissingFormatArgumentException.java,
* java/util/MissingFormatWidthException.java,
* java/util/PriorityQueue.java,
* java/util/Queue.java,
* java/util/UnknownFormatConversionException.java,
* java/util/UnknownFormatFlagsException.java,
* org/omg/CORBA/SendingContext/RunTimeOperations.java,
* org/omg/CORBA/SendingContext/Runtime.java,
* vm/reference/java/lang/VMPackage.java:
Fixed address within GPL.

-- 
Andrew :-)

Please avoid sending me Microsoft Office (e.g. Word, PowerPoint) attachments.
See http://www.fsf.org/philosophy/no-word-attachments.html

Value your freedom, or you will lose it, teaches history. 
`Don't bother us with politics' respond those who don't want to learn. 
-- Richard Stallman

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: gnu/classpath/ByteArray.java
===
RCS file: /cvsroot/classpath/classpath/gnu/classpath/ByteArray.java,v
retrieving revision 1.1.2.1
diff -u -3 -p -u -r1.1.2.1 ByteArray.java
--- gnu/classpath/ByteArray.java20 Sep 2005 18:46:23 -  1.1.2.1
+++ gnu/classpath/ByteArray.java21 Sep 2005 21:27:06 -
@@ -17,8 +17,8 @@ You should have received a copy of the G
 with GNU Classpath; if not, write to the
 
Free Software Foundation, Inc.,
-   59 Temple Place, Suite 330,
-   Boston, MA  02111-1307
+   51 Franklin Street, Fifth Floor,
+   Boston, MA  02110-1301
USA
 
 Linking this library statically or dynamically with other modules is
Index: gnu/classpath/ObjectPool.java
===
RCS file: /cvsroot/classpath/classpath/gnu/classpath/Attic/ObjectPool.java,v
retrieving revision 1.4.2.1
diff -u -3 -p -u -r1.4.2.1 ObjectPool.java
--- gnu/classpath/ObjectPool.java   2 Aug 2005 20:12:08 -   1.4.2.1
+++ gnu/classpath/ObjectPool.java   21 Sep 2005 21:27:07 -
@@ -15,8 +15,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Classpath; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA.
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
 
 Linking this library statically or dynamically with other modules is
 making a combined work based on this library.  Thus, the terms and
Index: java/math/BigInteger.java
===
RCS file: /cvsroot/classpath/classpath/java/math/BigInteger.java,v
retrieving revision 1.25
diff -u -r1.25 BigInteger.java
--- java/math/BigInteger.java   2 Jul 2005 20:32:39 -   1.25
+++ java/math/BigInteger.java   21 Sep 2005 16:59:08 -
@@ -76,7 +76,8 @@
   private static final long serialVersionUID = -8287574255936472291L;
 
 
   /** We pre-allocate integers in the range minFixNum..maxFixNum. */
   private static final int minFixNum = -100;
   private static final int maxFixNum = 1024;
   private static final int numFixNum = maxFixNum-minFixNum+1;
@@ -87,11 +88,23 @@
   smallFixNums[i] = new BigInteger(i + minFixNum);
   }
 
-  // JDK1.2
+  /**
+   * The constant zero as a BigInteger.
+   * @since 1.2
+   */
   public static final BigInteger ZERO = smallFixNums[-minFixNum];
 
-  // JDK1.2
+  /**
+   * The constant one as a BigInteger.
+   * @since 1.2
+   */
   public static final BigInteger ONE = smallFixNums[1 - minFixNum];
+  
+  /**
+   * The constant ten as a BigInteger.
+   * @since 1.5
+   */
+  public static final BigInteger TEN = smallFixNums[10 - minFixNum];
 
   /* Rounding modes: */
   private static final int FLOOR = 1;
@@ -76,7 +76,8 @@
 
 
-  /** We pre-allocate integers in the range minFixNum..maxFixNum. */
+  /** We pre-allocate integers in the range minFixNum..maxFixNum. 
+   * Note that we must at least preallocate 0, 1, and 10.  */
   private static final int minFixNum = -100;
   private static final int maxFixNum = 1024;


___
Classpath-patches mailing list
Classpath-patches@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-patches


[cp-patches] Patch: FYI: BorderLayout -vs- 1.5

2005-09-21 Thread Tom Tromey
I'm checking this in.

This updates BorderLayout with the new 1.5 functionality.  This also
fixes the serialization of this class.

I've added a Mauve test for the new methods.

Tom

Index: gnu/javax/crypto/DiffieHellmanImpl.java
===
RCS file: /cvsroot/classpath/classpath/gnu/javax/crypto/DiffieHellmanImpl.java,v
retrieving revision 1.1.2.1
diff -u -3 -p -u -r1.1.2.1 DiffieHellmanImpl.java
--- gnu/javax/crypto/DiffieHellmanImpl.java 20 Sep 2005 18:46:24 -  
1.1.2.1
+++ 

GNU Classpath CVS Write Access

2005-09-21 Thread Ranjit Mathew
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Hi,

  My paperwork with the FSF is through and I would like
to apply for write access to the Classpath CVS. Please
let me know what I need to do.

Thanks in advance,
Ranjit.

- --
Ranjit Mathew   Email: rmathew AT gmail DOT com

Bangalore, INDIA. Web: http://ranjitmathew.hostingzero.com/




-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.2 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFDMV0HYb1hx2wRS48RAg2+AJ9sjqFlR91lTa/MEfNpMEtp0SW+BgCdG/MX
D1rWdd1kmj1MlKhAlfKTBfU=
=nMJm
-END PGP SIGNATURE-



___
Classpath mailing list
Classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath


Re: GNU Classpath CVS Write Access

2005-09-21 Thread Mark Wielaard
Hi Ranjit,

On Wed, 2005-09-21 at 18:45 +0530, Ranjit Mathew wrote:
   My paperwork with the FSF is through and I would like
 to apply for write access to the Classpath CVS. Please
 let me know what I need to do.

Send the maintainer (me) an email with your savannah.gnu.org user name
(create a new one if you don't have one already).

Cheers,

Mark


signature.asc
Description: This is a digitally signed message part
___
Classpath mailing list
Classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath


Re: GNU Classpath CVS Write Access

2005-09-21 Thread Ranjit Mathew
On 9/21/05, Mark Wielaard [EMAIL PROTECTED] wrote:
 Hi Ranjit,

 On Wed, 2005-09-21 at 18:45 +0530, Ranjit Mathew wrote:
My paperwork with the FSF is through and I would like
  to apply for write access to the Classpath CVS. Please
  let me know what I need to do.

 Send the maintainer (me) an email with your savannah.gnu.org user name
 (create a new one if you don't have one already).

Thanks. My Savannah username is rmathew. My SSH
public key is already there.

Ranjit.

--
Ranjit Mathew  Email: rmathew AT gmail DOT com

Bangalore, INDIA.Web: http://ranjitmathew.hostingzero.com/


___
Classpath mailing list
Classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath


ServerSocket.getLocalPort possible bug...

2005-09-21 Thread Martin Cordova
Hello:

While testing Winstone servlet engine (winstone.sourceforge.net) on
JamVM 1.3.3 with Classpath 0.18, I found a possible bug:

getLocalPort returns -1 when it should return 80. In fact the same
program on the same box, when running with Sun or IBM JVM works fine.
So I suspect it may be a problem in ServerSocket implementation.

Winstone's author explained to me the following:

I know what this is - it's because socket.getLocalPort() returns -1. I
hit this when I was trying to run winstone on GCJ too, about 12 months
ago, but didn't report it. The listener code does:

   req.setServerPort(socket.getLocalPort());


I observed this bug when navigating to http://mylinuxBox from a remote
windows box using IE6, IE complained about no response. I found in the
servlet logs the following:

Headers prepared for writing: [Location: http://192.168.1.1:-1/index.htm

Which means that a redirect from root context to the welcome page was
being sent to the browser, but the -1 port troubled IE6.

Hope it helps.

Regards,
Martin
--
Dinamica - Open source J2EE framework
Free, easy and powerful
http://www.martincordova.com


___
Classpath mailing list
Classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath


Re: ServerSocket.getLocalPort possible bug...

2005-09-21 Thread Mark Wielaard
Hi Martin,

On Wed, 2005-09-21 at 13:20 -0400, Martin Cordova wrote:
 Winstone's author explained to me the following:
 
 I know what this is - it's because socket.getLocalPort() returns -1. I
 hit this when I was trying to run winstone on GCJ too, about 12 months
 ago, but didn't report it. The listener code does:
 
req.setServerPort(socket.getLocalPort());
 

Thanks for reporting the bug. For bonus points please file the bug
through http://www.gnu.org/software/classpath/bugs.html
That way it is easier to track (sadly sometimes bug just sent to the
mailinglist get lost in other conversations).

I don't have a patch yet, but a created the attached Mauve
(http://www.sourceware/org/mauve/) unit test that shows the issue:

FAIL: gnu/testlet/java/net/ServerSocket/AcceptGetLocalPort (number 2)
got -1 but expected 5678

Cheers,

Mark
/* AcceptGetLocalPort.java - Test for getLocalPort on accepted Socket.
   Copyright (C) 2005, Mark J. Wielaard  [EMAIL PROTECTED]

This file is part of Mauve.

Mauve is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

Mauve is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Mauve; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA. */
   
// Tags: JDK1.0

package gnu.testlet.java.net.ServerSocket;

import gnu.testlet.Testlet;
import gnu.testlet.TestHarness;

import java.net.*;
import java.io.*;

public class AcceptGetLocalPort implements Testlet, Runnable
{
  private static int port = 5678;

  public void test (TestHarness harness)
  {
new Thread(this).start();
try
  {
	ServerSocket ss = new ServerSocket(port);
	harness.check(ss.getLocalPort(), port);
	Socket s = ss.accept();
	harness.check(s.getLocalPort(), port);
	s.close();
	ss.close();
  }
catch (IOException ioe)
  {
	harness.debug(ioe);
	harness.check(false, ioe.toString());
  }
  }

  public void run()
  {
int i = 0;
while (i  10)
  {
	try
	  {
	Socket s = new Socket(localhost, port);
	break;
	  }
	catch (IOException ioe)
	  {
	// ignore
	  }
	try
	  {
	Thread.sleep(1000);
	  }
	catch (InterruptedException ie)
	  {
	// ignore
	  }
  }
  }
}


signature.asc
Description: This is a digitally signed message part
___
Classpath mailing list
Classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath


[commit-cp] classpath ./ChangeLog javax/swing/plaf/metal/Me...

2005-09-21 Thread David Gilbert
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: David Gilbert [EMAIL PROTECTED]   05/09/21 10:59:46

Modified files:
.  : ChangeLog 
Added files:
javax/swing/plaf/metal: MetalFileChooserUI.java 

Log message:
2005-09-21  David Gilbert  [EMAIL PROTECTED]

* javax/swing/plaf/metal/MetalFileChooserUI.java: new file
(partial
implementation).

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4895tr2=1.4896r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/plaf/metal/MetalFileChooserUI.java?rev=1.1





[commit-cp] classpath ./ChangeLog javax/swing/ToolTipManage...

2005-09-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   05/09/21 14:22:21

Modified files:
.  : ChangeLog 
javax/swing: ToolTipManager.java 

Log message:
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/ToolTipManager.java
(showTip): Added code to move currentPoint to a new place.
(getGoodPoint): Removed, not needed.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4896tr2=1.4897r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/ToolTipManager.java.diff?tr1=1.16tr2=1.17r1=textr2=text





[commit-cp] classpath ./ChangeLog javax/swing/plaf/basic/Ba...

2005-09-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   05/09/21 15:32:31

Modified files:
.  : ChangeLog 
javax/swing/plaf/basic: BasicOptionPaneUI.java 

Log message:
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

Fixes Bug #23937
* javax/swing/plaf/basic/BasicOptionPaneUI.java
(propertyChange): When WANTS_INPUT_PROPERTY is changed,
the buttons should be updated.
(getButtons): Applied patch in bug report. Sets default
buttons.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4897tr2=1.4898r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/plaf/basic/BasicOptionPaneUI.java.diff?tr1=1.23tr2=1.24r1=textr2=text





[commit-cp] classpath ./ChangeLog java/math/BigInteger.java...

2005-09-21 Thread Tom Tromey
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Tom Tromey [EMAIL PROTECTED]  05/09/21 17:00:33

Modified files:
.  : ChangeLog 
java/math  : BigInteger.java BigDecimal.java 

Log message:
* java/math/BigDecimal.java (ZERO, ONE): Now public.  Updated
javadoc.
(TEN): New constant.
* java/math/BigInteger.java (ZERO): Updated javadoc.
(ONE): Likewise.
(TEN): New constant.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4898tr2=1.4899r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/java/math/BigInteger.java.diff?tr1=1.25tr2=1.26r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/java/math/BigDecimal.java.diff?tr1=1.19tr2=1.20r1=textr2=text





[commit-cp] classpath/org/omg DynamicAny/DynAnyFactoryPacka... [generics-branch]

2005-09-21 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: generics-branch
Changes by: Andrew John Hughes [EMAIL PROTECTED]  05/09/21 18:07:07

Added files:
org/omg/DynamicAny/DynAnyFactoryPackage: 
 InconsistentTypeCode.java 
 
InconsistentTypeCodeHelper.java 
org/omg/DynamicAny/DynAnyPackage: InvalidValue.java 
  InvalidValueHelper.java 
  TypeMismatch.java 
  TypeMismatchHelper.java 
  package.html 
org/omg/PortableServer/POAPackage: AdapterAlreadyExists.java 
   AdapterAlreadyExistsHelper.java 
   AdapterNonExistent.java 
   AdapterNonExistentHelper.java 
   InvalidPolicy.java 
   InvalidPolicyHelper.java 
   NoServant.java 
   NoServantHelper.java 
   ObjectAlreadyActive.java 
   ObjectAlreadyActiveHelper.java 
   ObjectNotActive.java 
   ObjectNotActiveHelper.java 
   ServantAlreadyActive.java 
   ServantAlreadyActiveHelper.java 
   ServantNotActive.java 
   ServantNotActiveHelper.java 
   WrongAdapter.java 
   WrongAdapterHelper.java 
   WrongPolicy.java 
   WrongPolicyHelper.java 
Removed files:
org/omg/SendingContext: RunTime.java RunTimeOperations.java 

Log message:
2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

Fixing some strangely absent files...

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyFactoryPackage/InconsistentTypeCode.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyFactoryPackage/InconsistentTypeCodeHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyPackage/InvalidValue.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyPackage/InvalidValueHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyPackage/TypeMismatch.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyPackage/TypeMismatchHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/DynamicAny/DynAnyPackage/package.html?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/AdapterAlreadyExists.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/AdapterAlreadyExistsHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/AdapterNonExistent.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/AdapterNonExistentHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/InvalidPolicy.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/InvalidPolicyHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/NoServant.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/NoServantHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/ObjectAlreadyActive.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAPackage/ObjectAlreadyActiveHelper.java?only_with_tag=generics-branchrev=1.2.2.1

[commit-cp] classpath/org/omg IOP/CodecFactoryPackage/Unkno... [generics-branch]

2005-09-21 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: generics-branch
Changes by: Andrew John Hughes [EMAIL PROTECTED]  05/09/21 18:11:28

Added files:
org/omg/IOP/CodecFactoryPackage: UnknownEncoding.java 
 UnknownEncodingHelper.java 
org/omg/IOP/CodecPackage: FormatMismatch.java 
  FormatMismatchHelper.java 
  InvalidTypeForEncoding.java 
  InvalidTypeForEncodingHelper.java 
  TypeMismatch.java 
  TypeMismatchHelper.java 
org/omg/PortableInterceptor/ORBInitInfoPackage: 
DuplicateName.java 

DuplicateNameHelper.java 
InvalidName.java 
InvalidNameHelper.java 
ObjectIdHelper.java 
org/omg/PortableServer/CurrentPackage: NoContext.java 
   NoContextHelper.java 
org/omg/PortableServer/POAManagerPackage: AdapterInactive.java 
  AdapterInactiveHelper.java 
  State.java 
  package.html 
org/omg/PortableServer/ServantLocatorPackage: CookieHolder.java 
  package.html 

Log message:
2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

* More oddly missing files.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecFactoryPackage/UnknownEncoding.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecFactoryPackage/UnknownEncodingHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/FormatMismatch.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/FormatMismatchHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/InvalidTypeForEncoding.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/InvalidTypeForEncodingHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/TypeMismatch.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/IOP/CodecPackage/TypeMismatchHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/DuplicateName.java?only_with_tag=generics-branchrev=1.3.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/DuplicateNameHelper.java?only_with_tag=generics-branchrev=1.3.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/InvalidName.java?only_with_tag=generics-branchrev=1.3.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/InvalidNameHelper.java?only_with_tag=generics-branchrev=1.3.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/ObjectIdHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/CurrentPackage/NoContext.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/CurrentPackage/NoContextHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAManagerPackage/AdapterInactive.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAManagerPackage/AdapterInactiveHelper.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAManagerPackage/State.java?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/POAManagerPackage/package.html?only_with_tag=generics-branchrev=1.2.2.1
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/org/omg/PortableServer/ServantLocatorPackage/CookieHolder.java?only_with_tag=generics-branchrev=1.1.2.1

[commit-cp] classpath ./ChangeLog javax/swing/text/html/HTM...

2005-09-21 Thread Anthony Balkissoon
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Anthony Balkissoon [EMAIL PROTECTED]  05/09/21 18:21:57

Modified files:
.  : ChangeLog 
javax/swing/text/html: HTMLDocument.java 

Log message:
2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTMLDocument.java:
(LeafIterator): New class.
(getIterator): Implemented.
(Iterator): New abstract class.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4899tr2=1.4900r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/text/html/HTMLDocument.java.diff?tr1=1.2tr2=1.3r1=textr2=text





[commit-cp] classpath ./ChangeLog javax/swing/JTable.java j...

2005-09-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   05/09/21 18:57:45

Modified files:
.  : ChangeLog 
javax/swing: JTable.java ToolTipManager.java 

Log message:
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/JTable.java
(distributeSpill): Fixed a NPE.
* javax/swing/ToolTipManager.java
(mouseExited): No need to do this stuff, removed code.
(showTip): Revalidating and repainting too much, removed.
(hideTip): Likewise.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4901tr2=1.4902r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/JTable.java.diff?tr1=1.47tr2=1.48r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/ToolTipManager.java.diff?tr1=1.17tr2=1.18r1=textr2=text





[commit-cp] classpath ./ChangeLog java/awt/BorderLayout.java

2005-09-21 Thread Tom Tromey
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Tom Tromey [EMAIL PROTECTED]  05/09/21 18:38:22

Modified files:
.  : ChangeLog 
java/awt   : BorderLayout.java 

Log message:
* java/awt/BorderLayout.java (invalidateLayout): Updated comment.
(setBounds): Likewise.
(MIN, MAX, PREF): Moved nearer top of file.
(getLayoutComponent): New methods.
(getConstraints): New method.
(vgap, hgap, north, south, east, west): Reordered fields to conform
to serialization spec.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4900tr2=1.4901r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/java/awt/BorderLayout.java.diff?tr1=1.18tr2=1.19r1=textr2=text





[commit-cp] classpath ./ChangeLog java/awt/BorderLayout.java

2005-09-21 Thread Tom Tromey
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Tom Tromey [EMAIL PROTECTED]  05/09/21 19:13:58

Modified files:
.  : ChangeLog 
java/awt   : BorderLayout.java 

Log message:
* java/awt/BorderLayout.java: Reverted field reordering.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4902tr2=1.4903r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/java/awt/BorderLayout.java.diff?tr1=1.19tr2=1.20r1=textr2=text





[commit-cp] classpath ./ChangeLog javax/swing/text/html/HTM...

2005-09-21 Thread Anthony Balkissoon
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Anthony Balkissoon [EMAIL PROTECTED]  05/09/21 19:27:29

Modified files:
.  : ChangeLog 
javax/swing/text/html: HTMLDocument.java 

Log message:
2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTMLDocument.java:
(getBase): Implemented.
(setBase): Implemented.
(getPreservesUnknownTags): Implemented.
(setPreservesUnknownTags): Implemented.
(BlockElement): New class partially implemented.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4903tr2=1.4904r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/text/html/HTMLDocument.java.diff?tr1=1.3tr2=1.4r1=textr2=text





[commit-cp] classpath ./ChangeLog lib/split-for-gcj.sh

2005-09-21 Thread Mark Wielaard
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Mark Wielaard [EMAIL PROTECTED]   05/09/21 20:50:23

Modified files:
.  : ChangeLog 
lib: split-for-gcj.sh 

Log message:
* lib/split-for-gcj.sh: Cut list to 3 package levels deep.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4905tr2=1.4906r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/lib/split-for-gcj.sh.diff?tr1=1.6tr2=1.7r1=textr2=text





[commit-cp] classpath ./ChangeLog javax/swing/text/html/HTM...

2005-09-21 Thread Anthony Balkissoon
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Anthony Balkissoon [EMAIL PROTECTED]  05/09/21 20:30:38

Modified files:
.  : ChangeLog 
javax/swing/text/html: HTML.java HTMLDocument.java 

Log message:
2005-09-21  Anthony Balkissoon  [EMAIL PROTECTED]

* javax/swing/text/html/HTML.java:
(Tag): Changed name of IMPLIED Tag from implied to p-implied to
match the JDK.
* javax/swing/text/html/HTMLDocument.java:
(AdditionalComments): New field.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4904tr2=1.4905r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/text/html/HTML.java.diff?tr1=1.5tr2=1.6r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/text/html/HTMLDocument.java.diff?tr1=1.4tr2=1.5r1=textr2=text





[commit-cp] classpath ./ChangeLog gnu/classpath/ByteArray.j...

2005-09-21 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Andrew John Hughes [EMAIL PROTECTED]  05/09/21 20:55:40

Modified files:
.  : ChangeLog 
gnu/classpath  : ByteArray.java 
gnu/javax/crypto: DiffieHellmanImpl.java GnuDHPrivateKey.java 
  RSACipherImpl.java 

Log message:
2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

* gnu/classpath/ByteArray.java,
* gnu/javax/crypto/DiffieHellmanImpl.java,
* gnu/javax/crypto/GnuDHPrivateKey.java,
* gnu/javax/crypto/RSACipherImpl.java:
Fixed address within GPL license.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4906tr2=1.4907r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/gnu/classpath/ByteArray.java.diff?tr1=1.1tr2=1.2r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/gnu/javax/crypto/DiffieHellmanImpl.java.diff?tr1=1.1tr2=1.2r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/gnu/javax/crypto/GnuDHPrivateKey.java.diff?tr1=1.1tr2=1.2r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/gnu/javax/crypto/RSACipherImpl.java.diff?tr1=1.1tr2=1.2r1=textr2=text





[commit-cp] classpath ./ChangeLog gnu/classpath/ByteArray.java

2005-09-21 Thread Mark Wielaard
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Mark Wielaard [EMAIL PROTECTED]   05/09/21 21:07:45

Modified files:
.  : ChangeLog 
gnu/classpath  : ByteArray.java 

Log message:
* gnu/classpath/ByteArray.java: Reindent boilerplate.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4907tr2=1.4908r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/gnu/classpath/ByteArray.java.diff?tr1=1.2tr2=1.3r1=textr2=text





[commit-cp] classpath ./ChangeLog javax/swing/ToolTipManage...

2005-09-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   05/09/21 21:21:19

Modified files:
.  : ChangeLog 
javax/swing: ToolTipManager.java 

Log message:
2005-09-21  Lillian Angel  [EMAIL PROTECTED]

* javax/swing/ToolTipManager.java
(showTip): Fixed location of tooltip. Sometimes
the ToolTip was being cut off.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4908tr2=1.4909r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/javax/swing/ToolTipManager.java.diff?tr1=1.18tr2=1.19r1=textr2=text





[commit-cp] classpath ./ChangeLog gnu/classpath/ByteArray.j... [generics-branch]

2005-09-21 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: generics-branch
Changes by: Andrew John Hughes [EMAIL PROTECTED]  05/09/21 21:32:40

Modified files:
.  : ChangeLog 
gnu/classpath  : ByteArray.java ObjectPool.java 
gnu/javax/crypto: DiffieHellmanImpl.java GnuDHPrivateKey.java 
  RSACipherImpl.java 
java/lang  : Deprecated.java Enum.java Iterable.java 
 MalformedParameterizedTypeException.java 
 Override.java ProcessBuilder.java 
 SuppressWarnings.java 
java/lang/annotation: Annotation.java Documented.java 
  ElementType.java 
  IncompleteAnnotationException.java 
  Inherited.java Retention.java 
  RetentionPolicy.java Target.java 
java/lang/reflect: AnnotatedElement.java GenericDeclaration.java 
   MalformedParameterizedTypeException.java 
   TypeVariable.java 
java/util  : AbstractQueue.java 
 DuplicateFormatFlagsException.java EnumMap.java 
 EnumSet.java 
 FormatFlagsConversionMismatchException.java 
 FormatterClosedException.java 
 IllegalFormatCodePointException.java 
 IllegalFormatConversionException.java 
 IllegalFormatException.java 
 IllegalFormatFlagsException.java 
 IllegalFormatPrecisionException.java 
 IllegalFormatWidthException.java 
 InputMismatchException.java 
 InvalidPropertiesFormatException.java 
 MissingFormatArgumentException.java 
 MissingFormatWidthException.java 
 PriorityQueue.java Queue.java 
 UnknownFormatConversionException.java 
 UnknownFormatFlagsException.java 
org/omg/CORBA/SendingContext: RunTimeOperations.java 
  Runtime.java 
vm/reference/java/lang: VMPackage.java 

Log message:
2005-09-21  Andrew John Hughes  [EMAIL PROTECTED]

* gnu/classpath/ByteArray.java,
* gnu/classpath/ObjectPool.java,
* gnu/javax/crypto/DiffieHellmanImpl.java,
* gnu/javax/crypto/GnuDHPrivateKey.java,
* gnu/javax/crypto/RSACipherImpl.java,
* java/lang/Deprecated.java,
* java/lang/Enum.java,
* java/lang/Iterable.java,
* java/lang/MalformedParameterizedTypeException.java,
* java/lang/Override.java,
* java/lang/ProcessBuilder.java,
* java/lang/SuppressWarnings.java,
* java/lang/annotation/Annotation.java,
* java/lang/annotation/Documented.java,
* java/lang/annotation/ElementType.java,
* java/lang/annotation/IncompleteAnnotationException.java,
* java/lang/annotation/Inherited.java,
* java/lang/annotation/Retention.java,
* java/lang/annotation/RetentionPolicy.java,
* java/lang/annotation/Target.java,
* java/lang/reflect/AnnotatedElement.java,
* java/lang/reflect/GenericDeclaration.java,
* java/lang/reflect/MalformedParameterizedTypeException.java,
* java/lang/reflect/TypeVariable.java,
* java/util/AbstractQueue.java,
* java/util/DuplicateFormatFlagsException.java,
* java/util/EnumMap.java,
* java/util/EnumSet.java,
* java/util/FormatFlagsConversionMismatchException.java,
* java/util/FormatterClosedException.java,
* java/util/IllegalFormatCodePointException.java,
* java/util/IllegalFormatConversionException.java,
* java/util/IllegalFormatException.java,
* java/util/IllegalFormatFlagsException.java,
* java/util/IllegalFormatPrecisionException.java,
* java/util/IllegalFormatWidthException.java,
* java/util/InputMismatchException.java,
* java/util/InvalidPropertiesFormatException.java,
* java/util/MissingFormatArgumentException.java,
* java/util/MissingFormatWidthException.java,
* java/util/PriorityQueue.java,
* java/util/Queue.java,
* java/util/UnknownFormatConversionException.java,
* java/util/UnknownFormatFlagsException.java,
* org/omg/CORBA/SendingContext/RunTimeOperations.java,
* org/omg/CORBA/SendingContext/Runtime.java,
* vm/reference/java/lang/VMPackage.java:
Fixed address within GPL.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?only_with_tag=generics-branchtr1=1.2386.2.132tr2=1.2386.2.133r1=textr2=text

[commit-cp] classpath ./ChangeLog java/lang/ClassLoader.java

2005-09-21 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Andrew John Hughes [EMAIL PROTECTED]  05/09/21 22:35:33

Modified files:
.  : ChangeLog 
java/lang  : ClassLoader.java 

Log message:
2004-10-09  Tom Tromey  [EMAIL PROTECTED]

* java/lang/ClassLoader.java
(defineClass(String,ByteBuffer,ProtectionDomain)): New method.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.4909tr2=1.4910r1=textr2=text
http://savannah.gnu.org/cgi-bin/viewcvs/classpath/classpath/java/lang/ClassLoader.java.diff?tr1=1.57tr2=1.58r1=textr2=text